function [y,t]=glottal_pulse(Fs,F,Tf,a)
%------------------------------------------------------------------------
%  Esta funcion genera un tren de impulsos de 
%  amplitud unitaria, con las siguientes caracteristicas:
%  	Fs: frecuencia de muestreo
%  	F:  frecuencia del tren de impulsos
%  	Tf: tiempo total
%  	t:  vector tiempo (intervalo de muestreo = 1/Fs)
%  que luego es filtrado con un modelo exponencial de la glotis, dado por
%
%                        -1
%            -a e ln(a) z
%     G(z)=-------------------
%                     -1  2
%             (1 - a z   )
%
%  	y:  vector conteniendo el tren de pulsos de glotis
%  Nota: con a=0.75 , los pulsos resultan de amplitud aprox = 1
%------------------------------------------------------------------------
%  Uso:
%		[y,t]=glottal_pulse(Fs,F,Tf,a)
%------------------------------------------------------------------------
%  Juan Carlos Gomez - 10/10/2001.
%------------------------------------------------------------------------
ee=exp(1);
num=[-a*ee*log(a) 0];
den=[1 -2*a a^2];
[Y,t]=tren_impulsos(Fs,F,Tf);
[y,xx]=dlsim(num,den,Y);